#ifndef LIB_MSG_H
#define LIB_MSG_H

/* Beginning of labels */
#define TMSG_LIB_X11_ERR		0
#define TMSG_LIB_CONFIRM		1
#define TMSG_MISSING_ALPHABET		2
#define TMSG_OLD_VIEW_NOT_REPLACED		3
#define TMSG_OLD_SCH_TO_RECOMP		4
#define TMSG_MISSING_FONT		5
#define TMSG_NO_MEMORY		6
#define TMSG_UNABLE_TO_CONNECT_TO_X		7
#define TMSG_VIEW_MODIFIED_BEFORE_CREATION		8
#define TMSG_LIB_RULES_TABLE_FULL		9
#define TMSG_INCORRECT_STR_FILE		10
#define TMSG_INCORRECT_PRS_FILE		11
#define TMSG_DOC_PRINTED		12
#define TMSG_REDUCTION		13
#define TMSG_1_PAGE_SHEET		14
#define TMSG_2_PAGE_SHEET		15
#define TMSG_4_PAGE_SHEET		16
#define TMSG_LIB_STRING		17
#define TMSG_NOT_ENOUGH_MEMORY		18
#define TMSG_DEBUG_ERROR		19
#define TMSG_DEBUG_SAV_FILES		20
#define TMSG_TRA_FILE_INCORRECT		21
#define TMSG_INVALID_SIBLING		22
#define TMSG_INVALID_CHILD		23
#define TMSG_PAGE		24
#define TMSG_LANGUAGE		25
#define TMSG_ATTR		26
#define TMSG_STD_PRES		27
#define TMSG_APPLY		28
#define TMSG_CHAR		29
#define TMSG_LINE		30
#define TMSG_GRAPHICS_PRES		31
#define TMSG_FORMAT		32
#define TMSG_UNCHANGED		33
#define TMSG_ALIGN		34
#define TMSG_INDENT		35
#define TMSG_LIB_PRINTING_IN_PROGRESS		36
#define TMSG_LIB_PRINT		37
#define TMSG_MANUAL_FEED		38
#define TMSG_OPTIONS		39
#define TMSG_A4		40
#define TMSG_US		41
#define TMSG_PAPER_SIZE		42
#define TMSG_DONE		43
#define TMSG_DOC_DIR		44
#define TMSG_FILE_EXIST		45
#define TMSG_BUTTON_1		46
#define TMSG_BUTTON_2		47
#define TMSG_FONT_FAMILY		48
#define TMSG_ROMAN		49
#define TMSG_BOLD		50
#define TMSG_ITALIC		51
#define TMSG_OBLIQUE		52
#define TMSG_NOT_BOLD		53
#define TMSG_BOLDNESS		54
#define TMSG_NORMAL		55
#define TMSG_UNDERLINE		56
#define TMSG_CROSS_OUT		57
#define TMSG_BODY_SIZE_PTS		58
#define TMSG_INDENT_PTS		59
#define TMSG_LINE_SPACING_PTS		60
#define TMSG_LINE_SPACING		61
#define TMSG_SAVE_DOC		62
#define TMSG_CLOSE_DON_T_SAVE		63
#define TMSG_STYLE		64
#define TMSG_COLORS		65
#define TMSG_XHTML		66
#define TMSG_DEL		67
#define TMSG_OUTPUT		68
#define TMSG_PS_FILE		69
#define TMSG_PRINTER		70
#define TMSG_SEARCH_FOR		71
#define TMSG_UPPERCASE_EQ_LOWERCASE		72
#define TMSG_REPLACE_BY		73
#define TMSG_REPLACE		74
#define TMSG_NO_REPLACE		75
#define TMSG_REPLACE_ON_REQU		76
#define TMSG_AUTO_REPLACE		77
#define TMSG_SEARCH_WHERE		78
#define TMSG_BEFORE_SEL		79
#define TMSG_WITHIN_SEL		80
#define TMSG_AFTER_SEL		81
#define TMSG_IN_WHOLE_DOC		82
#define TMSG_DO_NOT_REPLACE		83
#define TMSG_STD_COLORS		84
#define TMSG_BEFORE_CLOSING		85
#define TMSG_CLOSE_DOC		86
#define TMSG_MATH_SYMBOLS		87
#define TMSG_GRAPHICS		88
#define TMSG_LATIN_ALPHABET		89
#define TMSG_GREEK_ALPHABET		90
#define TMSG_SAVE		91
#define TMSG_TEXT		92
#define TMSG_GRAPHIC		93
#define TMSG_SYMBOL		94
#define TMSG_PICTURE		95
#define TMSG_EL_TYPE		96
#define TMSG_AFTER		97
#define TMSG_BEFORE		98
#define TMSG_AROUND		99
#define TMSG_INCLUDE		100
#define TMSG_PASTE		101
#define TMSG_TO_CREATE		102
#define TMSG_INSERT		103
#define TMSG_PAGE_BRK		104
#define TMSG_LANG_OF_EL		105
#define TMSG_INHERITED_LANG		106
#define TMSG_NOT_FOUND		107
#define TMSG_SEARCH_IN		108
#define TMSG_SEARCH		109
#define TMSG_EL_RO		110
#define TMSG_NOTHING_TO_REPLACE		111
#define TMSG_STD_CHAR		112
#define TMSG_STD_GRAPHICS		113
#define TMSG_STD_FORMAT		114
#define TMSG_STD_GEOMETRY		115
#define TMSG_TYPOGRAPHIC_POINTS		116
#define TMSG_LINE_STYLE		117
#define TMSG_LINE_WEIGHT		118
#define TMSG_FILL_PATTERN		119
#define TMSG_SPLIT		120
#define TMSG_OBJECT_TYPE		121
#define TMSG_GOTO_PAGE		122
#define TMSG_ANY		123
#define TMSG_ATTR_TO_SEARCH		124
#define TMSG_TYPE_TO_SEARCH		125
#define TMSG_NATURES		126
#define TMSG_ATTRIBUTE_NAME		127
#define TMSG_ATTRIBUTE_VALUE		128
#define TMSG_VALUE_OF_ATTR		129
#define TMSG_UNKNOWN_ATTR		130
#define TMSG_CANCEL		131
#define TMSG_ERROR_PS_TRANSLATION		132
#define TMSG_UNKNOWN_PRINTER		133
#define TMSG_CANNOT_CREATE_PS		134
#define TMSG_OVERLINE		135
#define TMSG_DOCUMENT_FORMAT		136
#define TMSG_EVENTS		137
#define TMSG_DEL_ATTR		138
#define TMSG_CPBUTTON_1		139
#define TMSG_CPBUTTON_2		140
#define TMSG_CPMOREBUTTON		141
#define TMSG_CPGETBUTTON		142
#define TMSG_CPCOLORBUTTON		143
#define TMSG_CPCOLORBG		144
#define TMSG_CPCOLORFG		145
#define TMSG_CPCOLORSWITCH		146
#define TMSG_NO_ELEMENT		147
#define TMSG_What		148
#define TMSG_Pass_Without		149
#define TMSG_Replace_With		150
#define TMSG_Replace_Without		151
#define TMSG_Keep_Unknown		152
#define TMSG_Pass_With		153
#define TMSG_Specials		154
#define TMSG_Correct		155
#define TMSG_Romans		156
#define TMSG_Ignore		157
#define TMSG_Capitals		158
#define TMSG_Arabics		159
#define TMSG_NO_PARAM		160
#define TMSG_NO_KEYBOARD		161
#define TMSG_NO_SAVE		162
#define TMSG_REFUSE_WORD		163
#define TMSG_ADD_WORD		164
#define TMSG_END_CHECK		165
#define TMSG_STOP_CHECK		166
#define TMSG_NO_SELECT		167
#define TMSG_OK_SAVE		168
#define TMSG_NOT_AVAILABLE		169
#define TMSG_ATTACHDETACH		170
#define TMSG_TOOLS		171
#define TMSG_ATTR_MANDATORY		172
#define TMSG_REFRESH		173
#define TMSG_FORMATLEFT		174
#define TMSG_FORMATRIGHT		175
#define TMSG_FORMATCENTER		176
#define TMSG_FORMATJUSTIFY		177
#define TMSG_APPLY_CLASS		178
#define TMSG_SEL_CLASS		179
#define TMSG_SEL		180
#define TMSG_DISCARD		181
#define TMSG_MATHML		182
#define TMSG_MISC		183
#define TMSG_BINARY_REL		184
#define TMSG_BINARY_REL_NEG		185
#define TMSG_OPERATOR		186
#define TMSG_GREEK_CAP		187
#define TMSG_ARROW		188
#define TMSG_SPECHAR		189
#define TMSG_BUTTON_INTERRUPT		190
#define TMSG_BUTTON_PREVIOUS		191
#define TMSG_BUTTON_NEXT		192
#define TMSG_BUTTON_RELOAD		193
#define TMSG_BUTTON_SAVE		194
#define TMSG_BUTTON_NEW		195
#define TMSG_BUTTON_OPEN		196
#define TMSG_BUTTON_PRINT		197
#define TMSG_BUTTON_SEARCH		198
#define TMSG_BUTTON_HOME		199
#define TMSG_BUTTON_ITALICS		200
#define TMSG_BUTTON_BOLD		201
#define TMSG_BUTTON_CODE		202
#define TMSG_BUTTON_IMG		203
#define TMSG_BUTTON_H1		204
#define TMSG_BUTTON_H2		205
#define TMSG_BUTTON_H3		206
#define TMSG_BUTTON_UL		207
#define TMSG_BUTTON_OL		208
#define TMSG_BUTTON_DL		209
#define TMSG_BUTTON_LINK		210
#define TMSG_BUTTON_TABLE		211
#define TMSG_LIB_WARNCTAB_INFO		212
#define TMSG_LIB_WARNCTAB_CHECK		213
#define TMSG_LIB_CLOSETABS		214
#define TMSG_LIB_NOERROR_DOC		215
#define TMSG_LIB_ERROR_DOC		216
#define TMSG_LIB_BOXES		217
#define TMSG_BUTTON_DIV		218
#define TMSG_BUTTON_TARGET		219
#define TMSG_INSERTION		220
#define TMSG_DELETION		221
#define TMSG_SUB		222
#define TMSG_SUP		223
#define TMSG_BUTTON_DT		224
#define TMSG_BUTTON_DD		225
#define TMSG_OBJECT		226
#define TMSG_CSSStyle		227
#define TMSG_EXPLORE		228
#define TMSG_SplitHorizontally		229
#define TMSG_SplitVertically		230
#define TMSG_ShowPanel		231
#define TMSG_LIB_MSG_MAX		232

#endif
